@@ -34,7 +34,7 @@ def pull_images(images):
 
 def check_env_vars(*args, **kwargs):
     missing = []
-    not_required = ['psql_image', 'push_image', 'install']
+    not_required = ['psql_image', 'push_image', 'install', 'allow_deprecated']
     for key in args:
         if key not in not_required and not (key.upper() in environ and environ[key.upper()]):
             missing.append(key.upper())
@@ -209,7 +209,6 @@ def get_config(**kwargs):
     res.update({
         'main_app': get_main_app(res)
     })
-    print(res.get('main_app'))
     return res
 
 
@@ -245,11 +244,17 @@ def scan_keys(folder):
     known_hosts = path.join(folder, 'known_hosts')
     with open(known_hosts, 'a') as known_file:
         for host in TO_SCAN:
-            keys = subprocess.check_output(['ssh-keyscan', host], stderr=subprocess.STDOUT)
-            for line in utils.decode(keys).split('\n'):
-                clean = line.strip()
-                if clean:
-                    known_file.write(clean + '\n')
+            try:
+                keys = subprocess.check_output(['ssh-keyscan', host], stderr=subprocess.STDOUT)
+            except subprocess.CalledProcessError as error:
+                _logger.warn(('Could not scan % host, if you get any error cloning '
+                              'from this provider, please try again later'), host)
+                _logger.warn('Error was: ', error.output)
+            else:
+                for line in utils.decode(keys).split('\n'):
+                    clean = line.strip()
+                    if clean:
+                        known_file.write(clean + '\n')
     subprocess.check_call(['ls', '-l', folder])
 
 
@@ -375,7 +380,7 @@ def exec_cmd(container, cmd, user=None, stream=False):
 
 
 def create_postgres_user(config):
-    cmd = "psql -c \"create user odoo with password 'odoo' createdb\""
+    cmd = "psql -c \"create user odoo with password 'odoo' superuser\""
     retry = 0
     while retry < 4:
         res = exec_cmd(config['postgres_container'], cmd, 'postgres')
@@ -437,30 +442,36 @@ def install_module(config):
     _logger.info('\nInstalling %s with demo', module)
     _logger.debug('Command : %s', install_wdemo)
     wdemo_res = exec_cmd(config['container_name'], install_wdemo, 'odoo', stream=True)
-    wdemo_log = resume_log(wdemo_res)
+    wdemo_log = resume_log(wdemo_res, config['allow_deprecated'])
     _logger.info('\nInstalling %s without demo', module)
     _logger.debug('Command : %s', install_wodemo)
     wodemo_res = exec_cmd(config['container_name'], install_wodemo, 'odoo', stream=True)
-    wodemo_log = resume_log(wodemo_res)
-    show_log(wdemo_log[1], 'Installation with demo')
-    show_log(wodemo_log[1], 'Installation without demo')
+    wodemo_log = resume_log(wodemo_res, config['allow_deprecated'])
+    show_log(wdemo_log[1], 'Installation with demo', config)
+    show_log(wodemo_log[1], 'Installation without demo', config)
+    _logger.debug('Installation wdemo res: %s', wdemo_log[0])
+    _logger.debug('Installation wodemo res: %s', wodemo_log[0])
     if not wdemo_log[0] or not wodemo_log[0]:
         return False
     return True
 
 
-def show_log(log, title):
-    _logger.info('\n%s', title)
-    _logger.info('='*20)
+def show_log(log, title, config):
+    _logger.info('='*50)
+    _logger.info('%s', title)
+    if config['allow_deprecated']:
+        _logger.warning('+++ Deprecated methods allowed')
+    _logger.info('='*50)
     _logger.info('+-- Critical errors %s', len(log.get('critical')))
     _logger.info('+-- Errors %s', len(log.get('errors')))
     _logger.info('+-- Import errors %s', len(log.get('import_errors')))
+    _logger.info('+-- Deprecation Warnings %s', len(log.get('warnings_deprecated')))
     _logger.info('+-- Warnings %s', len(log.get('warnings')))
     _logger.info('+-- Translation Warnings %s', len(log.get('warnings_trans')))
-    _logger.info('='*20)
+    _logger.info('*'*50)
 
 
-def resume_log(log_lines):
+def resume_log(log_lines, allow_deprecated=False):
     """Gets the log lines from -u (modules or all) and parse them to get the totals
     according to the filters dict
 
@@ -480,32 +491,43 @@ def resume_log(log_lines):
             r'.*\d\sWARNING\s.*no translation for language.*')
         return criteria.match(line)
 
+    def warnings_deprecated(line):
+        criteria = re.compile(
+            r'.*\d\sWARNING\s.*Deprecated method.*')
+        return criteria.match(line)
+
     def import_errors(line):
         criteria = re.compile(r'^ImportError.*')
         return criteria.match(line)
 
     def warnings(line):
         criteria = re.compile(r'.*\d\sWARNING\s.*')
-        return criteria.match(line) and 'no translation for language' not in line
+        return criteria.match(line) \
+            and 'no translation for language' not in line \
+            and 'Deprecated method' not in line
 
     filters = {
         'critical': critical,
         'errors': errors,
         'warnings': warnings,
         'warnings_trans': warnings_trans,
+        'warnings_deprecated': warnings_deprecated,
         'import_errors': import_errors
     }
     success = True
     res = {name: [] for name in filters}
+    warn_to_replace = '\x1b[1;33m\x1b[1;49mWARNING\x1b[0m'
     for line in log_lines:
-        stripped_line = line.strip()
+        original_line = line.strip()
+        # Remove colorized when exists to regex
+        stripped_line = original_line.replace(warn_to_replace, 'WARNING')
         for name, criteria in filters.items():
             if criteria(stripped_line):
                 if name in ['critical', 'errors']:
                     success = False
-                elif name == 'warnings' and 'Deprecated' in stripped_line:
+                elif name == 'warnings_deprecated' and not allow_deprecated:
                     success = False
-                res.get(name).append(stripped_line)
+                res.get(name).append(original_line)
                 break
     return success, res
 
